import "./main.css";
import $5OpyM$react, {useState as $5OpyM$useState, useRef as $5OpyM$useRef, useEffect as $5OpyM$useEffect} from "react";



function $cd990771233444d0$var$Autocomplete({ field: field , size: size , onTermSelected: onTermSelected , apiKey: apiKey ,  }) {
    const [searchTerm, setSearchTerm] = $5OpyM$useState('');
    const [searchResults, setSearchResults] = $5OpyM$useState([]);
    const [focus, setFocus] = $5OpyM$useState(false);
    const [errorMessage, setErrorMessage] = $5OpyM$useState('');
    const [isLoading, setIsLoading] = $5OpyM$useState(false);
    const [isActive, setIsActive] = $5OpyM$useState(0);
    const timer = $5OpyM$useRef(null);
    const autoInput = document.querySelector('.pdl-auto-input');
    const clearResults = ()=>{
        setSearchResults([]);
    };
    const fetchResults = async ()=>{
        setErrorMessage('');
        setIsActive(0);
        if (!focus) return;
        setIsLoading(true);
        if (searchTerm.length === 0) {
            setIsLoading(false);
            clearTimeout(timer.current);
            clearResults();
            return;
        }
        let reqURL = `https://api.peopledatalabs.com/v5/autocomplete?field=${field}&text=${searchTerm}`;
        if (size !== undefined) reqURL += `&size=${size}`;
        const response = await fetch(reqURL, {
            headers: {
                'X-API-Key': `${apiKey}`
            }
        });
        const data = await response.json();
        if (data.status !== 200) {
            switch(data.status){
                case 404:
                    clearResults();
                    setIsLoading(false);
                    setErrorMessage('No results');
                    break;
                case 403:
                    clearResults();
                    setIsLoading(false);
                    setErrorMessage('Unauthorized API key');
                    break;
                case 401:
                    clearResults();
                    setIsLoading(false);
                    setErrorMessage('API key required');
                    break;
                case 429:
                    clearResults();
                    setIsLoading(false);
                    setErrorMessage('API rate limit reached');
                    break;
                default:
                    clearResults();
                    setIsLoading(false);
                    setErrorMessage(data.error.message);
                    break;
            }
            return;
        }
        setSearchResults(data.data);
        setIsLoading(false);
    };
    const debounce = (cb, delay = 250)=>{
        clearTimeout(timer.current);
        return ()=>{
            timer.current = setTimeout(()=>{
                cb();
            }, delay);
        };
    };
    $5OpyM$useEffect(()=>{
        if (focus) debounce(fetchResults)();
    }, [
        searchTerm,
        focus
    ]);
    const blur = ()=>{
        setFocus(false);
        autoInput.blur();
    };
    const selectHandler = (e)=>{
        if (searchResults.length === 0) return;
        if (e.type === 'mousedown') {
            const selected = document.querySelector('.pdl-selected');
            const selectedTerm = selected.getAttribute('value');
            setSearchTerm(selectedTerm);
            onTermSelected(selectedTerm);
            blur();
            return;
        }
        switch(e.key){
            case 'Enter':
                {
                    const selected = document.querySelector('.pdl-selected');
                    const selectedTerm = selected.getAttribute('value');
                    setSearchTerm(selectedTerm);
                    onTermSelected(selectedTerm);
                    blur();
                    break;
                }
            case 'ArrowDown':
                if (isActive === searchResults.length - 1 || isActive === null) setIsActive(0);
                else {
                    const toAdd = isActive;
                    setIsActive(toAdd + 1);
                }
                break;
            case 'ArrowUp':
                if (isActive === 0 || isActive === null) setIsActive(searchResults.length - 1);
                else {
                    const toSubtract = isActive;
                    setIsActive(toSubtract - 1);
                }
                break;
            case 'Escape':
                blur();
                break;
            default:
                break;
        }
    };
    const placeholderText = ()=>{
        switch(field){
            case 'company':
                return 'IE: people data labs';
            case 'country':
                return 'IE: ["united states"]';
            case 'industry':
                return 'IE: computer software';
            case 'location':
                return 'IE: berkeley, california, united states';
            case 'major':
                return 'IE: ["entrepreneurship"]';
            case 'region':
                return 'IE: ["california, united states"]';
            case 'role':
                return 'IE: operations';
            case 'sub_role':
                return 'IE: logistics';
            case 'school':
                return 'IE: university of texas at austin';
            case 'skill':
                return 'IE: data analysis';
            case 'title':
                return 'IE: co-founder and chief executive officer';
            default:
                return '';
        }
    };
    return /*#__PURE__*/ $5OpyM$react.createElement("div", {
        className: "pdl-autocomplete-wrapper"
    }, /*#__PURE__*/ $5OpyM$react.createElement("div", {
        className: `pdl-auto-input-wrapper pdl-df pdl-row ${focus ? 'pdl-input-wrapper-focus' : ''}`
    }, /*#__PURE__*/ $5OpyM$react.createElement("input", {
        className: "pdl-auto-input",
        placeholder: placeholderText(),
        value: searchTerm,
        onChange: (e)=>setSearchTerm(e.currentTarget.value)
        ,
        onFocus: ()=>setFocus(true)
        ,
        onBlur: ()=>setFocus(false)
        ,
        onKeyDown: (e)=>selectHandler(e)
    }), /*#__PURE__*/ $5OpyM$react.createElement("div", {
        className: `pdl-loading-spinner ${isLoading ? '' : 'pdl-dn'}`
    })), /*#__PURE__*/ $5OpyM$react.createElement("div", {
        className: "pdl-autocomplete"
    }, /*#__PURE__*/ $5OpyM$react.createElement("div", {
        className: `pdl-suggestions ${!focus || !searchResults.length ? 'pdl-dn' : ''}`
    }, searchResults.length > 0 ? searchResults.map((searchResult, idx)=>/*#__PURE__*/ $5OpyM$react.createElement("div", {
            key: idx,
            className: `pdl-suggestion pdl-df pdl-row ${idx === isActive ? 'pdl-selected' : ''}`,
            value: searchResult.name,
            "data-idx": idx,
            onMouseOver: (e)=>setIsActive(parseInt(e.currentTarget.dataset.idx, 10))
            ,
            onMouseDown: (e)=>selectHandler(e)
        }, /*#__PURE__*/ $5OpyM$react.createElement("div", {
            className: "pdl-suggestion-name"
        }, searchResult.name), /*#__PURE__*/ $5OpyM$react.createElement("div", {
            className: "pdl-suggestion-count"
        }, searchResult.count ? `(${searchResult.count.toLocaleString('en-US')})` : null))
    ) : null), /*#__PURE__*/ $5OpyM$react.createElement("div", {
        className: `pdl-suggestions-pending
          ${focus === false || isLoading || errorMessage || searchResults.length > 0 ? 'pdl-dn' : ''}`
    }, "Start typing to get suggestions"), /*#__PURE__*/ $5OpyM$react.createElement("div", {
        className: `pdl-suggestions-error
          ${errorMessage.length === 0 || !focus || searchTerm.length === 0 ? 'pdl-dn' : ''}`
    }, errorMessage)));
}
var $cd990771233444d0$export$2e2bcd8739ae039 = $cd990771233444d0$var$Autocomplete;



var $cf838c15c8b009ba$export$2e2bcd8739ae039 = $cd990771233444d0$export$2e2bcd8739ae039;


export {$cf838c15c8b009ba$export$2e2bcd8739ae039 as default};
//# sourceMappingURL=index.mjs.map
